# Icarus Api

_用以提供开发时的补全提示_
## 0.0.9
- utils
  - 增加notice 调用系统通知 _(toast)_
- net
  - 完善net包提示
##0.0.8
- net
  - 增加request

##0.0.7
- utils
  - 增加walkdir，unzip
- net
  - 增加download

##0.0.6
- ICARUS
  - 增加shell_fetch，kill_task
## 0.0.5
整理api格式

## 0.0.4
- fofa
- coding
- pwn
- vault


## 0.0.3
- docker

## 0.0.2
- utils.color

## 0.0.1
- ICARUS
- utils